@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_iot._jsii
@@ -19,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-iot-lambda-dynamodb",
-    "1.61.0",
+    "1.64.0",
     __name__[0:-6],
-    "aws-iot-lambda-dynamodb@1.61.0.jsii.tgz",
+    "aws-iot-lambda-dynamodb@1.64.0.jsii.tgz",
 )
 
 __all__ = [
